/*
* INSTANCE
*/
resource "aws_instance" "perforce_01" {
  ami                         = "${data.aws_ami.amazon_linux.id}"
  instance_type               = "${var.instance_type}"
  subnet_id                   = "${module.networking.az-subnet-id-mapping["subnet1"]}"
  // associate_public_ip_address = true
  key_name                    = "${aws_key_pair.key_pair.key_name}"
  user_data                   = "${data.template_file.cloud_config.rendered}"
  vpc_security_group_ids = [
    "${aws_security_group.instance_sg.id}",
  ]
  root_block_device           = {
    volume_size = 20
  }
  tags {
    Name = "${var.stack_name}-${var.env}-perforce-01"
  }
}

// resource "aws_eip" "eip_01" {
//   instance = "${aws_instance.perforce_01.id}"
//   vpc      = true
//   tags {
//     Name = "${var.stack_name}-${var.env}-01-eip"
//   }
// }

/*
* Metadata volume and attachment
* Not encrypted for performance reasons
*/
resource "aws_ebs_volume" "perforce_01_hxmetadata" {
    availability_zone = "${data.aws_availability_zones.available.names[0]}"
    size = 20
    encrypted   = false
    tags {
        Name = "perforce-01-hxmetadata"
    }
}

resource "aws_volume_attachment" "perforce_01_hxmetadata_att" {
  device_name = "/dev/sdh"
  volume_id   = "${aws_ebs_volume.perforce_01_hxmetadata.id}"
  instance_id = "${aws_instance.perforce_01.id}"
}

/*
* Logs volume and attachment
*/
resource "aws_ebs_volume" "perforce_01_hxlogs" {
    availability_zone = "${data.aws_availability_zones.available.names[0]}"
    size = 20
    encrypted   = true
    tags {
        Name = "perforce-01-hxlogs",
        Snapshot = "snapshot-yes"
    }
}

resource "aws_volume_attachment" "perforce_01_hxlogs_att" {
  device_name = "/dev/sdi"
  volume_id   = "${aws_ebs_volume.perforce_01_hxlogs.id}"
  instance_id = "${aws_instance.perforce_01.id}"
}

/*
* Depots volume and attachment
*/
resource "aws_ebs_volume" "perforce_01_hxdepots" {
    availability_zone = "${data.aws_availability_zones.available.names[0]}"
    size = 20
    encrypted   = true
    tags {
        Name = "perforce-01-hxdepots",
        Snapshot = "snapshot-yes"
    }
}

resource "aws_volume_attachment" "perforce_01_hxdepots_att" {
  device_name = "/dev/sdj"
  volume_id   = "${aws_ebs_volume.perforce_01_hxdepots.id}"
  instance_id = "${aws_instance.perforce_01.id}"
}
